@@ -17,16 +17,17 @@ class AsciiMol:
 
     def redraw(self):
         self.stdscr.clear()
-        self.draw_characters(self.renderer.content)
+        self.draw_renderer_buffer()
         self.draw_navbar()
         self.stdscr.refresh()
         self.sig_changed = False
 
-    def draw_characters(self, content: list):
-        for i in range(curses.LINES - 2):
-            for j in range(curses.COLS):
-                char, col = content[i][j].split(",")
-                self.stdscr.addstr(i, j, char, int(col))
+    def draw_renderer_buffer(self):
+        content = self.renderer.content
+        for key in content:
+            y, x = key
+            char, col, _ = content[key]
+            self.stdscr.addstr(y, x, char, int(col))
 
     def draw_navbar(self):
         x, y, z = self.renderer.rotcounter
@@ -37,11 +38,10 @@ class AsciiMol:
         navbar_string += "[↔↕] Rotate (%-3.f, %-3.f, %-3.f) " % (x, y, z)
         navbar_string += "[Z] ↔ Y/Z rotation (%s) " % ztoggle_str
         navbar_string += "[WSAD] Navigate "
-        navbar_string += "[C] Center "
         navbar_string += "[T] Principle Axes "
         navbar_string += "[F1-3] Auto-Rotate"
         try:
-            self.stdscr.addstr(navbar_string)
+            self.stdscr.addstr(curses.LINES - 2, 0, navbar_string)
         except curses.error:
             if curses.LINES > 1 and curses.COLS > 3:
                 self.stdscr.addstr(curses.LINES - 1, curses.COLS - 4, "...")
@@ -57,8 +57,6 @@ class AsciiMol:
                 self.sig_changed = self.renderer.navigate(dx=-ceil(self.renderer.zoom))
             if 68 in keys or 100 in keys:  # D
                 self.sig_changed = self.renderer.navigate(dx=ceil(self.renderer.zoom))
-            if 67 in keys or 99 in keys:  # C
-                self.sig_changed = self.renderer.center()
             if 84 in keys or 116 in keys:  # T
                 self.sig_changed = self.renderer.prinicple_axes()
             if curses.KEY_F1 in keys:
@@ -110,8 +108,8 @@ class AsciiMol:
             self.renderer.auto_rotate()
             self.sig_changed = True
         if self.sig_changed:
+            self.renderer.buffer_scene()
             try:
-                self.renderer.buffer_scene()
                 self.redraw()
                 self.timeout = 0
             except curses.error:
